@@ -15,8 +15,10 @@ test_that("slurm_job name is correctly edited", {
 })
 
 olddir <- getwd()
+rscript_path <- file.path(R.home("bin"), "Rscript")
 setwd(paste0("_rslurm_", sjob$jobname))
-tryCatch(system("Rscript --vanilla slurm_run.R"), finally = setwd(olddir))
+tryCatch(system(paste(rscript_path, "--vanilla slurm_run.R")), 
+         finally = setwd(olddir))
 res <- get_slurm_out(sjob)
 
 test_that("slurm_call returns correct output", {
